export declare type IdEntity = {
    id: string;
};
export declare type NumericIdEntity = {
    id: number;
};
export interface IValueConverter<D, V> {
    convert?: IItemValueConverter<D, V>;
    convertBack?: IItemValueConverter<V, D>;
}
export interface IItemValueConverter<D, V> {
    (from: D): V;
}
export interface IInputValueConverter<D> extends IValueConverter<D, string> {
}
export declare class CheckboxValueConverter<D> implements IValueConverter<D, boolean> {
    private trueValue;
    private falseValue;
    constructor(trueValue: D, falseValue: D);
    convert(data: D): boolean;
    convertBack(value: boolean): D;
}
export declare class IdEntityValueConverter implements IInputValueConverter<IdEntity> {
    convertBack: IItemValueConverter<string, IdEntity>;
    constructor(convertBack: IItemValueConverter<string, IdEntity>);
    convert(data: IdEntity): string;
}
export declare class IdValueConverter implements IInputValueConverter<string> {
    convertBack: IItemValueConverter<string, string>;
    constructor(convertBack: IItemValueConverter<string, string>);
    convert(data: string): string;
}
export declare class NumericIdEntityValueConverter implements IInputValueConverter<NumericIdEntity> {
    convertBack: IItemValueConverter<string, NumericIdEntity>;
    constructor(convertBack: IItemValueConverter<string, NumericIdEntity>);
    convert(data: NumericIdEntity): string;
}
export declare class NumericIdValueConverter implements IInputValueConverter<number> {
    convertBack: IItemValueConverter<string, number>;
    constructor(convertBack: IItemValueConverter<string, number>);
    convert(data: number): string;
}
export declare class DefaultValueConverter implements IInputValueConverter<string> {
    convert(data: string): string;
    convertBack(value: string): string;
    static instance: DefaultValueConverter;
}
export interface INumericOptions {
    allowNegative?: boolean;
    decimals?: number;
    min?: number;
    max?: number;
    step?: number;
}
export declare class NumericValueConverter implements IInputValueConverter<number> {
    private options;
    constructor(options?: INumericOptions);
    convert(data: number): string;
    convertBack(value: string): number;
}
