"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var React = require("react");
var ReactDOM = require("react-dom");
var _ = require("underscore");
var classBuilder_1 = require("./../../utilities/classBuilder");
var uiHelpers_1 = require("./../../utilities/uiHelpers");
var Grid = (function (_super) {
    __extends(Grid, _super);
    function Grid() {
        _super.apply(this, arguments);
    }
    Grid.prototype.render = function () {
        var originalClassName = this.props.className;
        var attrs = _.omit(this.props, "className", "debugMode", "table", "fillContainer");
        var classes = classBuilder_1.classNames(originalClassName, "grid", classBuilder_1.cd("fill-container", this.props.fillContainer), classBuilder_1.cd("grid-debug", this.props.debugMode), classBuilder_1.cd("table-grid", this.props.table));
        if (this.props.fillContainer && !this.props.disableFlexOverride) {
            return (React.createElement("div", {className: "flex-override"}, React.createElement("div", __assign({}, attrs, {className: classes}))));
        }
        else {
            return (React.createElement("div", __assign({}, attrs, {className: classes})));
        }
    };
    Grid.prototype.componentDidMount = function () {
        if (this.props.fillContainer && !this.props.disableFlexOverride) {
            ReactDOM.findDOMNode(this).parentElement.style.position = "relative";
        }
    };
    return Grid;
}(React.Component));
exports.Grid = Grid;
var Row = (function (_super) {
    __extends(Row, _super);
    function Row() {
        _super.apply(this, arguments);
    }
    Row.prototype.render = function () {
        var attrs = _.omit(this.props, "className", "fixed", "maxCols", "centerContent");
        var classes = classBuilder_1.classNames(this.props.className, "row", classBuilder_1.cd("no-flex", !!this.props.fixed), classBuilder_1.cd("wrap-row", !!this.props.maxCols));
        var styles = this.props.style;
        var colStyles;
        if (typeof this.props.fixed === "number") {
            styles = _.extend({ height: this.props.fixed + "px" }, styles);
        }
        if (this.props.maxCols) {
            colStyles = { flexBasis: 100 / this.props.maxCols + "%", maxWidth: 100 / this.props.maxCols + "%" };
        }
        return React.createElement("div", __assign({}, attrs, {className: classes, style: styles}), React.Children.map(this.props.children, function (c) {
            return c ? React.cloneElement(c, { style: colStyles ? _.extend(colStyles, c.props.style) : c.props.style }) : null;
        }));
    };
    return Row;
}(React.Component));
exports.Row = Row;
var Col = (function (_super) {
    __extends(Col, _super);
    function Col() {
        _super.apply(this, arguments);
    }
    Col.prototype.render = function () {
        var centerClasses = uiHelpers_1.LayoutHelpers.GetAlignment(this.props.centerContent);
        var classes = classBuilder_1.classNames("col", this.props.className, classBuilder_1.cd("no-flex", this.props.fixed !== undefined), classBuilder_1.cd("col" + this.props.spans, this.props.spans !== undefined), centerClasses);
        var attrs = _.omit(this.props, "className", "fixed", "spans", "centerContent");
        var styles = this.props.style;
        if (typeof this.props.fixed === "number") {
            styles = _.extend({ maxWidth: this.props.fixed + "px", width: "100%" }, styles);
        }
        return React.createElement("div", __assign({}, attrs, {className: classes, style: styles}));
    };
    return Col;
}(React.Component));
exports.Col = Col;
var SingleColumnRow = (function (_super) {
    __extends(SingleColumnRow, _super);
    function SingleColumnRow() {
        _super.apply(this, arguments);
    }
    SingleColumnRow.prototype.render = function () {
        var centerClasses = uiHelpers_1.LayoutHelpers.GetAlignment(this.props.centerContent);
        var classes = classBuilder_1.classNames("row", classBuilder_1.cd("no-flex", this.props.fixed !== undefined), this.props.className);
        var styles = this.props.style;
        var attrs = _.omit(this.props, "className", "fixed", "spans", "centerContent");
        return (React.createElement("div", __assign({}, attrs, {className: classes}), React.createElement("div", {className: classBuilder_1.classNames('col', centerClasses)}, this.props.children)));
    };
    return SingleColumnRow;
}(React.Component));
exports.SingleColumnRow = SingleColumnRow;
